@@ -12,7 +12,7 @@ use Lemonldap::NG::Portal::_LibAccess;
 use base qw(Lemonldap::NG::Portal::_LibAccess);
 use Clone qw(clone);
 
-our $VERSION = '1.2.2_01';
+our $VERSION  = '1.4.0';
 our $catlevel = 0;
 
 ## @method void menuInit()
@@ -35,7 +35,8 @@ sub menuInit {
 
     # Try to change password
     $self->{menuError} =
-      $self->_subProcess(qw(passwordDBInit modifyPassword sendPasswordMail))
+      $self->_subProcess(
+        qw(passwordDBInit modifyPassword passwordDBFinish sendPasswordMail))
       unless $self->{ignorePasswordChange};
 
     # Default menu error code
@@ -48,7 +49,7 @@ sub menuInit {
 
     # Default to appslist if invalid tab URL parameter
     $self->{menuDisplayTab} = "appslist"
-      unless ( $self->{menuDisplayTab} =~ /^(password|logout)$/ );
+      unless ( $self->{menuDisplayTab} =~ /^(password|logout|loginHistory)$/ );
 
     # Force password tab in case of password error
     $self->{menuDisplayTab} = "password"
@@ -57,6 +58,7 @@ sub menuInit {
             scalar(
                 grep { $_ == $self->{menuError} } (
                     25,    #PE_PP_CHANGE_AFTER_RESET
+                    26,    #PE_PP_PASSWORD_MOD_NOT_ALLOWED
                     27,    #PE_PP_MUST_SUPPLY_OLD_PASSWORD
                     28,    #PE_PP_INSUFFICIENT_PASSWORD_QUALITY
                     29,    #PE_PP_PASSWORD_TOO_SHORT
@@ -576,7 +578,15 @@ L<Lemonldap::NG::Portal>, L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
-Clement OUDOT E<lt>clement@oodo.netE<gt> E<lt>coudot@linagora.comE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=back
 
 =head1 BUG REPORT
 
@@ -590,12 +600,28 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005, 2007, 2010 by Clement OUDOT E<lt>clement@oodo.netE<gt>
-E<lt>coudot@linagora.comE<gt>
+=over
+
+=item Copyright (C) 2008, 2009, 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2012 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Copyright (C) 2008, 2009, 2010, 2011, 2012, 2013 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
 
